==> kaffeine_0.6.orig.tar.gz: kaffeine-0.6.orig/kaffeine/dvb/dvbsi.h <==
/***************************************************************************
                          dvbsi.h  -  description
                             -------------------
    begin                : 2004
    copyright            : (C) 2003-2005 by Christophe Thommeret
    email                : hftom@free.fr
    last modified        : $Date: 2005/02/02 10:08:25 $ by $Author: juergenk $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DVBSI_H
#define DVBSI_H

#include "dvbsection.h"
#include "dvbstream.h"



class DVBsi : public DVBsection
{
	Q_OBJECT

public: 

	DVBsi( bool *ok, int card, DvbStream *d );
	~DVBsi();
	bool getSection( int pid, int tid, int timeout=5000 );
	bool listChannels();
	bool tableSDT( unsigned char* buf );
	bool tablePAT( unsigned char *buf );
	bool tablePMT( unsigned char* buf );
	bool tableNIT( unsigned char* buf );
	void serviceDesc( unsigned char* buf, ChannelDesc *desc );
	void satelliteDesc( unsigned char* buf, Transponder *trans );
	void cableDesc( unsigned char* buf, Transponder *trans );
	void terrestrialDesc( unsigned char* buf, Transponder *trans );
	void freqListDesc( unsigned char* buf, Transponder *trans );

	QPtrList<ChannelDesc> channels;
	QPtrList<Transponder> transponders;
	DvbStream *dvb;
	int indexChannels;
	int progressTransponder;

public slots:

	void go( QPtrList<Transponder> trans, int mode=1 );
	void stop();

protected:

	virtual void run();
	virtual void timerEvent( QTimerEvent *e );

private:

	void out( bool stopscan=true );
	
	int scanMode;

signals:

	void end( bool );

};

#endif

==> kaffeine_0.7.1.orig.tar.gz: kaffeine-0.7.1/kaffeine/dvb/dvbsi.h <==
/***************************************************************************
                          dvbsi.h  -  description
                             -------------------
    begin                : 2004
    copyright            : (C) 2003-2005 by Christophe Thommeret
    email                : hftom@free.fr
    last modified        : $Date: 2005/07/21 19:40:30 $ by $Author: hftom $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DVBSI_H
#define DVBSI_H

#include <sys/poll.h>

#include "dvbsection.h"
#include "dvbstream.h"



class NitSection : public DVBsection
{

public:

	NitSection( QPtrList<Transponder> *tp, bool *end, bool *ok, int card );
	~NitSection();
	bool getSection( int pid, int tid, int timeout=5000 );
	bool tableNIT( unsigned char* buf );
	void satelliteDesc( unsigned char* buf, Transponder *trans );
	void cableDesc( unsigned char* buf, Transponder *trans );
	void terrestrialDesc( unsigned char* buf, Transponder *trans );
	void freqListDesc( unsigned char* buf, Transponder *trans );
	void stop();

	bool *ended;
	QPtrList<Transponder> *transponders;

protected:

	virtual void run();
	
private:
	struct pollfd pf[1];
};



class DVBsi : public DVBsection
{
	Q_OBJECT

public:

	DVBsi( bool *ok, int card, DvbStream *d );
	~DVBsi();
	bool getSection( int pid, int tid, int timeout=5000 );
	bool listChannels();
	bool tableSDT( unsigned char* buf );
	bool tablePAT( unsigned char *buf );
	bool tablePMT( unsigned char* buf );
	void serviceDesc( unsigned char* buf, ChannelDesc *desc );

	QPtrList<ChannelDesc> channels;
	QPtrList<Transponder> transponders;
	DvbStream *dvb;
	int indexChannels;
	int progressTransponder;
	int cardNum;

public slots:

	void go( QPtrList<Transponder> trans, int mode=1 );
	void stop();

protected:

	virtual void run();
	virtual void timerEvent( QTimerEvent *e );

private:

	void out( bool stopscan=true );

	int scanMode;
	NitSection *ns;
	struct pollfd pf[1];

signals:

	void end( bool );

};

#endif
